\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{pmfmo_phd}[2020/02/20 23:59 Doctoral Dissertation, PMF-MO, Zagreb, Croatia]
%
%%%%%%%%%% DOCUMENTCLASS %%%%%%%%%%
\LoadClass[a4paper, 12pt, oneside, openany]{book}
%
%%%%%%%%%% LANGUAGE AND CODING %%%%%%%%%%
\RequirePackage{ifpdf}
\RequirePackage[utf8]{inputenc}
\RequirePackage[english]{babel}
\RequirePackage{mathptmx}
%
%%%%%%%%%% AMS AND MATH %%%%%%%%%%
\RequirePackage{amssymb, amsmath, amsthm, amsfonts}
\RequirePackage{mathtools}
\RequirePackage{yhmath}
%
%%%%%%%%%% REST OF THE PACKAGES %%%%%%%%%%
\RequirePackage{multirow}
\RequirePackage{graphicx}
\RequirePackage{enumerate}
\RequirePackage{enumitem}
\RequirePackage{babelbib}
\RequirePackage{color}
\RequirePackage{xcolor}
\RequirePackage{etoolbox}
\RequirePackage{datatool}
\RequirePackage{xparse}
\RequirePackage{accsupp}
\RequirePackage{cite}
%
\definecolor{dark-blue}{rgb}{0.15,0.15,0.4}
\definecolor{medium-blue}{rgb}{0,0,0.5}
\definecolor{dark-red}{rgb}{0.4,0.15,0.15}
\RequirePackage[
	pagebackref=true,
	unicode=true,
	breaklinks=true,
	pdfsubject={doctoral dissertation},
	pdfstartpage={1},
	pdfstartview=FitH,
	linktocpage=false,
	bookmarksopen=true,
	bookmarksopenlevel=1,
	bookmarksnumbered=false,
	colorlinks=true,
	linkcolor={dark-blue},
	citecolor={medium-blue},
	urlcolor={dark-red},
	filecolor=yellow,
	]{hyperref}
\apptocmd{\sloppy}{\hbadness 10000\relax}{}{}
\renewcommand*{\backrefalt}[4]{
	\ifcase #1 %
	\else $\uparrow$ {\footnotesize #2.}%
	\fi
	}
\renewcommand*{\backreftwosep}{, }
\renewcommand*{\backreflastsep}{, }
%%%%%%%%%% MARGINS AND LINE SPREAD%%%%%%%%%%
\RequirePackage[margin=25mm,centering]{geometry}
\linespread{1.5}
%
%%%%%%%%%% PAGE NUMBERING DOWN-RIGHT %%%%%%%%%%
\RequirePackage{fancyhdr}
\pagestyle{fancy}
\setlength{\headheight}{15.14pt}
\renewcommand{\sectionmark}[1]{\markright{#1}}
\renewcommand{\chaptermark}[1]{\markboth{#1}{}}
\fancyhf{}
\renewcommand{\headrulewidth}{0.4pt}
\renewcommand{\footrulewidth}{0pt}
\lhead{\bfseries\nouppercase\leftmark}
\rhead{\itshape\nouppercase\rightmark}
\rfoot{\thepage}
\fancypagestyle{plain}{
	\fancyhf{}
	\renewcommand{\headrulewidth}{0pt}
	\renewcommand{\footrulewidth}{0pt}
	\rfoot{\thepage}
}
%
%%%%%%%%%% CHAPTER, SECTION, SUBSECTION, ... %%%%%%%%%%
\RequirePackage{titlesec}
\titleformat{\chapter}[hang]{\scshape\Huge\centering}{\thechapter.}{15pt}{}[]
\titleformat{\section}[hang]{\scshape\LARGE\centering}{\thesection.}{10pt}{}[]
\newcommand\sectionbreak{\ifthenelse{\value{section}>1}{\clearpage}{}}
\titleformat{\subsection}[hang]{\large}{\thesubsection.}{5pt}{}[]
%
%%%%%%%%%% CONFIGURATION COMMANDS %%%%%%%%%%
\newcommand*{\PMFMO}{PRIRODOSLOVNO--MATEMATI\v CKI FAKULTET\\MATEMATI\v CKI ODSJEK}
\newcommand*{\PMFMOeng}{FACULTY OF SCIENCE\\DEPARTMENT OF MATHEMATICS}
\newcommand*{\DOKTORSKI}{DOKTORSKI RAD}
\newcommand*{\DOKTORSKIeng}{DOCTORAL DISSERTATION}
\newcommand*\AUTHOR[1]{\renewcommand\@AUTOR{#1}}
\newcommand*\@AUTOR{Autor}
\newcommand*\TITLEhrv[1]{\renewcommand\@NASLOV{#1}}
\newcommand*\@NASLOV{Naslov}
\newcommand*\TITLE[1]{\renewcommand\@NASLOVeng{#1}}
\newcommand*\@NASLOVeng{Nasloveng}
\newcommand*\YEAR[1]{\renewcommand\@GODINA{#1}}
\newcommand*\@GODINA{0000}
\newcommand*\MJESTODATUM{Zagreb, \@GODINA.}
%%%%%%%%%% SUPERVISOR - ONE OR MORE OF THEM (COMMA SEPARATED!!)
\newcommand*\kolikomentora{0}
\newcommand*\SUPERVISOR[1]{
	\renewcommand\@MENTOR{#1}
	\DTLnumitemsinlist{\@MENTOR}{\kolikomentora}
}
\newcommand*\@MENTOR{Mentor}
\newcommand*\MENTORISPIS{
	\ifthenelse{\kolikomentora > 1}%
		{Mentori}{Mentor}:\\\@MENTOR
	}
\newcommand*\SUPERVISORISPIS{
	\ifthenelse{\kolikomentora > 1}%
		{Supervisors}{Supervisor}:\\\@MENTOR
	}
%THANKS
\newif\ifthanks
\thanksfalse
%EMPTYSTYLE FIRST PAGES
\newcommand*\GRB[1]{
	\thispagestyle{empty}
	\begin{figure}[h!]
		\centering
		\includegraphics[height=3.9cm]{basics/#1}
	\end{figure}
	}
%%%%%%%%%% FONT SIZE COMMAND
\newcommand*\@MOJFONT[2]{\fontsize{#1pt}{#2pt}\selectfont}
%
%%%%%%%%%% TITLEPAGE(S) %%%%%%%%%%
\renewcommand\titlepage{
	\pagenumbering{gobble}
	\newgeometry{margin=30mm,centering}
	{\fontfamily{phv}\selectfont
	\begin{center}
	%%%%%%%%%%  COVER  %%%%%%%%%%
	\GRB{logo_ver5en.pdf}
	{\@MOJFONT{16}{19}
		\PMFMOeng
		\vskip 50pt
		\@AUTOR}
	\vskip 110pt
	\@MOJFONT{22}{26}\textbf{\@NASLOVeng}
	\vskip 50pt
	\@MOJFONT{16}{19}\DOKTORSKIeng
	\vfill
	\@MOJFONT{14}{17}\MJESTODATUM
	\newpage
	%%%%%%%%%%  FIRST PAGE  %%%%%%%%%%
	\GRB{logo_ver5en.pdf}
	{\@MOJFONT{16}{19}
		\PMFMOeng
		\vskip 40pt
		\@AUTOR}
	\vskip 50pt
	\@MOJFONT{22}{26}\textbf{\@NASLOVeng}
	\vskip 50pt
	{\@MOJFONT{16}{19}
		\DOKTORSKIeng
		\vskip 50pt
		\SUPERVISORISPIS}
	\vfill
	\@MOJFONT{14}{17}\MJESTODATUM
	\newpage
	%%%%%%%%%%  SECOND PAGE  %%%%%%%%%%
	\GRB{logo_ver5hr.pdf}
	{\@MOJFONT{16}{19}
		\PMFMO
		\vskip 40pt
		\@AUTOR}
	\vskip 50pt
	\@MOJFONT{22}{26}\textbf{\@NASLOV}
	\vskip 50pt
	{\@MOJFONT{16pt}{19}
		\DOKTORSKI
		\vskip 50pt
		\MENTORISPIS}
	\vfill
	\@MOJFONT{14}{17}\MJESTODATUM
	\newpage
	\restoregeometry
	\pagenumbering{roman}
	\end{center}}
}
%
%%%%%%%%%% FRONTMATTER %%%%%%%%%%
\setcounter{tocdepth}{2}
\renewcommand\frontmatter{
	\titlepage
	\ifthanks \input{basics/thanks} \fi
	\input{basics/summary}
	\input{basics/sazetak}
	\tableofcontents
}
%
%%%%%%%%%% STYLE OF THEOREMS, LEMMAS, ETC. %%%%%%%%%%
\newtheoremstyle{style}{}{}{}{0pt}{\bfseries}{.}{10pt}{}
\theoremstyle{style}
\newtheorem{thm}{Theorem}[section]
\newtheorem{prop}[thm]{Proposition}
\newtheorem{cor}[thm]{Corollary}
\newtheorem{lem}[thm]{Lemma}
\newtheorem{dfn}[thm]{Definition}
\newtheorem{rem}[thm]{Remark}
\newtheorem*{thm*}{Theorem}
\newtheorem*{prop*}{Proposition}
\newtheorem*{cor*}{Corollary}
\newtheorem*{lem*}{Lemma}
\newtheorem*{dfn*}{Definition}
\newtheorem*{rem*}{Remark}
\renewcommand{\qedsymbol}{\ensuremath{\blacksquare}}
%
%%%%%%%%%% BIBLIOGRAPHY %%%%%%%%%%
\newcommand*{\Bibliography}[1]{
	\nocite{*}
	\bibliographystyle{babplain}
	\cleardoublepage
	\phantomsection
	\addcontentsline{toc}{chapter}{\bibname}
	\bibliography{#1}
}
%